@@ -5,7 +5,9 @@ def add_defaults(d, dflts):
     """Adds defaults to every (mapping) value of every item of d"""
     dflt_keys = set(dflts)
     for k, v in d.items():
-        d[k].update({dflt_key: dflts[dflt_key] for dflt_key in dflt_keys.difference(v)})
+        d[k].update(
+            {dflt_key: dflts[dflt_key] for dflt_key in dflt_keys.difference(v)}
+        )
     return d
 
 
@@ -15,7 +17,8 @@ class ModuleNotFoundErrorNiceMessage:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if exc_type is ModuleNotFoundError:
-            raise ModuleNotFoundError(f"""
+            raise ModuleNotFoundError(
+                f'''
 It seems you don't have requred `{exc_val.name}` package.
 Try installing it by running:
 
@@ -23,7 +26,8 @@ Try installing it by running:
 
 in your terminal.
 For more information: https://pypi.org/project/{exc_val.name}
-            """)
+            '''
+            )
 
 
 class I2mintModuleNotFoundErrorNiceMessage:
@@ -32,11 +36,13 @@ class I2mintModuleNotFoundErrorNiceMessage:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if exc_type is ModuleNotFoundError:
-            raise ModuleNotFoundError(f"""
+            raise ModuleNotFoundError(
+                f'''
 It seems you don't have requred `{exc_val.name}` package. Not sure if this is the problem, but you could try:
     git clone https://github.com/i2mint/{exc_val.name}
 in a place that your python path (i.e. PYTHONPATH environment variable).  
-            """)
+            '''
+            )
 
 
 def is_jsonable(x):
